Module native

Module native 

Native plugin adapter.

Provides NativePluginRule<P> which wraps a Plugin implementation into a LintRule, allowing WASM plugins to be run natively without WASM VM or serialization overhead.

This is used internally by nginx-lint to embed builtin plugins directly into the binary when built with the wasm-builtin-plugins feature.

Example

use nginx_lint_plugin::prelude::*;
use nginx_lint_plugin::native::NativePluginRule;

// Wrap a plugin as a native lint rule
let rule = NativePluginRule::<MyPlugin>::new();
// `rule` now implements LintRule and can be registered in the linter

Structs

NativePluginRule
Adapter that wraps a Plugin implementation into a LintRule.